==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emr/kotlin/inputs/ClusterCoreInstanceGroupEbsConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.inputs

import com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property iops Number of I/O operations per second (IOPS) that the volume supports.
 * @property size Volume size, in gibibytes (GiB).
 * @property throughput The throughput, in mebibyte per second (MiB/s).
 * @property type Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
 * @property volumesPerInstance Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
 */
public data class ClusterCoreInstanceGroupEbsConfigArgs(
    public val iops: Output<Int>? = null,
    public val size: Output<Int>,
    public val throughput: Output<Int>? = null,
    public val type: Output<String>,
    public val volumesPerInstance: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs> {
    override fun toJava(): com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs =
        com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs.builder()
            .iops(iops?.applyValue({ args0 -> args0 }))
            .size(size.applyValue({ args0 -> args0 }))
            .throughput(throughput?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 }))
            .volumesPerInstance(volumesPerInstance?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterCoreInstanceGroupEbsConfigArgs].
 */
@PulumiTagMarker
public class ClusterCoreInstanceGroupEbsConfigArgsBuilder internal constructor() {
    private var iops: Output<Int>? = null

    private var size: Output<Int>? = null

    private var throughput: Output<Int>? = null

    private var type: Output<String>? = null

    private var volumesPerInstance: Output<Int>? = null

    /**
     * @param value Number of I/O operations per second (IOPS) that the volume supports.
     */
    @JvmName("rgfjuxsvggyppusl")
    public suspend fun iops(`value`: Output<Int>) {
        this.iops = value
    }

    /**
     * @param value Volume size, in gibibytes (GiB).
     */
    @JvmName("epqjbyanvgdqttdy")
    public suspend fun size(`value`: Output<Int>) {
        this.size = value
    }

    /**
     * @param value The throughput, in mebibyte per second (MiB/s).
     */
    @JvmName("osvtvvuuyxmtgiho")
    public suspend fun throughput(`value`: Output<Int>) {
        this.throughput = value
    }

    /**
     * @param value Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
     */
    @JvmName("dcsgwxriukemwiqm")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
     */
    @JvmName("vpvemglmfobquneg")
    public suspend fun volumesPerInstance(`value`: Output<Int>) {
        this.volumesPerInstance = value
    }

    /**
     * @param value Number of I/O operations per second (IOPS) that the volume supports.
     */
    @JvmName("qtodtfdkuhgpqeuk")
    public suspend fun iops(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iops = mapped
    }

    /**
     * @param value Volume size, in gibibytes (GiB).
     */
    @JvmName("tuxhmragmipbtxni")
    public suspend fun size(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.size = mapped
    }

    /**
     * @param value The throughput, in mebibyte per second (MiB/s).
     */
    @JvmName("uocbprlqdaavugcu")
    public suspend fun throughput(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.throughput = mapped
    }

    /**
     * @param value Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
     */
    @JvmName("pcomehmhvniipims")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
     */
    @JvmName("rhvmqcetwtrylspa")
    public suspend fun volumesPerInstance(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.volumesPerInstance = mapped
    }

    internal fun build(): ClusterCoreInstanceGroupEbsConfigArgs =
        ClusterCoreInstanceGroupEbsConfigArgs(
            iops = iops,
            size = size ?: throw PulumiNullFieldException("size"),
            throughput = throughput,
            type = type ?: throw PulumiNullFieldException("type"),
            volumesPerInstance = volumesPerInstance,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emr/kotlin/inputs/ClusterCoreInstanceGroupEbsConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.inputs

import com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property iops Number of I/O operations per second (IOPS) that the volume supports.
 * @property size Volume size, in gibibytes (GiB).
 * @property throughput The throughput, in mebibyte per second (MiB/s).
 * @property type Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
 * @property volumesPerInstance Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
 */
public data class ClusterCoreInstanceGroupEbsConfigArgs(
    public val iops: Output<Int>? = null,
    public val size: Output<Int>,
    public val throughput: Output<Int>? = null,
    public val type: Output<String>,
    public val volumesPerInstance: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs> {
    override fun toJava(): com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs =
        com.pulumi.aws.emr.inputs.ClusterCoreInstanceGroupEbsConfigArgs.builder()
            .iops(iops?.applyValue({ args0 -> args0 }))
            .size(size.applyValue({ args0 -> args0 }))
            .throughput(throughput?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 }))
            .volumesPerInstance(volumesPerInstance?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterCoreInstanceGroupEbsConfigArgs].
 */
@PulumiTagMarker
public class ClusterCoreInstanceGroupEbsConfigArgsBuilder internal constructor() {
    private var iops: Output<Int>? = null

    private var size: Output<Int>? = null

    private var throughput: Output<Int>? = null

    private var type: Output<String>? = null

    private var volumesPerInstance: Output<Int>? = null

    /**
     * @param value Number of I/O operations per second (IOPS) that the volume supports.
     */
    @JvmName("qpuersmvcdpqnlrn")
    public suspend fun iops(`value`: Output<Int>) {
        this.iops = value
    }

    /**
     * @param value Volume size, in gibibytes (GiB).
     */
    @JvmName("tijuolgtohlfrubc")
    public suspend fun size(`value`: Output<Int>) {
        this.size = value
    }

    /**
     * @param value The throughput, in mebibyte per second (MiB/s).
     */
    @JvmName("nebbkjclpqddtkfo")
    public suspend fun throughput(`value`: Output<Int>) {
        this.throughput = value
    }

    /**
     * @param value Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
     */
    @JvmName("wfwsmnylluwqothp")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
     */
    @JvmName("iuincqgkgspweydl")
    public suspend fun volumesPerInstance(`value`: Output<Int>) {
        this.volumesPerInstance = value
    }

    /**
     * @param value Number of I/O operations per second (IOPS) that the volume supports.
     */
    @JvmName("bjuhemcydfegmofp")
    public suspend fun iops(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iops = mapped
    }

    /**
     * @param value Volume size, in gibibytes (GiB).
     */
    @JvmName("rlvbwavlteyxsxmp")
    public suspend fun size(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.size = mapped
    }

    /**
     * @param value The throughput, in mebibyte per second (MiB/s).
     */
    @JvmName("xvawamwgjywxsbkq")
    public suspend fun throughput(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.throughput = mapped
    }

    /**
     * @param value Volume type. Valid options are `gp3`, `gp2`, `io1`, `standard`, `st1` and `sc1`. See [EBS Volume Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html).
     */
    @JvmName("oifnldgxrdabvtgv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Number of EBS volumes with this configuration to attach to each EC2 instance in the instance group (default is 1).
     */
    @JvmName("shlydglvluojfces")
    public suspend fun volumesPerInstance(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.volumesPerInstance = mapped
    }

    internal fun build(): ClusterCoreInstanceGroupEbsConfigArgs =
        ClusterCoreInstanceGroupEbsConfigArgs(
            iops = iops,
            size = size ?: throw PulumiNullFieldException("size"),
            throughput = throughput,
            type = type ?: throw PulumiNullFieldException("type"),
            volumesPerInstance = volumesPerInstance,
        )
}
